==> sanofi-ui-vue-0.3.6.tgz: package/packages/index.js <==
import SnfAvatar from "./snf-avatar/index.js";
import SnfBadge from "./snf-badge/index.js";
import SnfButton from "./snf-button/index.js";
import SnfButtonGroup from "./snf-button-group/index.js";
import SnfCounter from "./snf-counter/index.js";
import SnfInput from "./snf-input/index.js";
import SnfTabbar from "./snf-tabbar/index.js";
import SnfTab from "./snf-tab/index.js";
import SnfTabGroup from "./snf-tab-group/index.js";
import SnfToggle from "./snf-toggle/index.js";
import SnfToggleField from "./snf-toggle-field/index.js";
import SnfCheckbox from "./snf-checkbox/index.js";
import SnfCheckboxField from "./snf-checkbox-field/index.js";
import SnfRadio from "./snf-radio/index.js";
import SnfRadioField from "./snf-radio-field/index.js";
import SnfProgress from "./snf-progress/index.js";
import SnfRate from "./snf-rate/index.js";
import SnfTag from "./snf-tag/index.js";
import SnfImage from "./snf-image/index.js";
import SnfFeatureEntry from "./snf-feature-entry/index.js";
// import SnfList from "./snf-list/index.js";
// import SnfListItem from "./snf-list-item/index.js";

import './default/index.css';
// import './default/base.css';
// import './default/snf-avatar.scss';
// import './default/snf-badge.scss';
// import './default/snf-button.scss';
// import './default/snf-button-group.scss';
// import './default/snf-counter.scss';
// import './default/snf-tabbar.scss';
// import './default/snf-tab.scss';
// import './default/snf-toggle.scss';
// import './default/snf-checkbox.scss';
// import './default/snf-radio.scss';
// import './default/snf-input.scss';
// import './default/snf-progress.scss';
// import './default/snf-rate.scss';
// import './default/snf-tag.scss';
// import './default/snf-list.scss';
// import './default/snf-image.scss';
// import './default/snf-feature-entry.scss';

const components = [
	SnfAvatar,
	SnfBadge,
	SnfButton,
	SnfButtonGroup,
	SnfCounter,
	SnfTabbar,
	SnfTab,
	SnfTabGroup,
	SnfToggle,
	SnfToggleField,
	SnfCheckbox,
	SnfCheckboxField,
	SnfRadio,
	SnfRadioField,
	SnfInput,
	SnfProgress,
	SnfRate,
	SnfTag,
	SnfImage,
	SnfFeatureEntry,
	// SnfList,
	// SnfListItem
];

const install = function(Vue) {
	
  if (install.installed) return;
  components.forEach(component => {
	  
    Vue.component(component.name, component)
	
  });
};
// 判断是否是直接引入文件
if (typeof window !== "undefined" && window.Vue) {
    
  install(window.Vue);
}
export default {
    
  install

}

==> sanofi-ui-vue-0.4.0.tgz: package/packages/index.js <==
import SnfAvatar from "./snf-avatar/index.js";
import SnfBadge from "./snf-badge/index.js";
import SnfButton from "./snf-button/index.js";
import SnfButtonGroup from "./snf-button-group/index.js";
import SnfCounter from "./snf-counter/index.js";
import SnfInput from "./snf-input/index.js";
import SnfTabbar from "./snf-tabbar/index.js";
import SnfTab from "./snf-tab/index.js";
import SnfTabGroup from "./snf-tab-group/index.js";
import SnfToggle from "./snf-toggle/index.js";
import SnfToggleField from "./snf-toggle-field/index.js";
import SnfCheckbox from "./snf-checkbox/index.js";
import SnfCheckboxField from "./snf-checkbox-field/index.js";
import SnfRadio from "./snf-radio/index.js";
import SnfRadioField from "./snf-radio-field/index.js";
import SnfProgress from "./snf-progress/index.js";
import SnfRate from "./snf-rate/index.js";
import SnfTag from "./snf-tag/index.js";
import SnfImage from "./snf-image/index.js";
import SnfFeatureEntry from "./snf-feature-entry/index.js";
import SnfList from "./snf-list/index.js";
import SnfListItem from "./snf-list-item/index.js";

import './default/index.css';
// import './default/base.css';
// import './default/snf-avatar.scss';
// import './default/snf-badge.scss';
// import './default/snf-button.scss';
// import './default/snf-button-group.scss';
// import './default/snf-counter.scss';
// import './default/snf-tabbar.scss';
// import './default/snf-tab.scss';
// import './default/snf-toggle.scss';
// import './default/snf-checkbox.scss';
// import './default/snf-checkbox-field.scss';
// import './default/snf-radio.scss';
// import './default/snf-radio-field.scss';
// import './default/snf-input.scss';
// import './default/snf-progress.scss';
// import './default/snf-rate.scss';
// import './default/snf-tag.scss';
// import './default/snf-list.scss';
// import './default/snf-image.scss';
// import './default/snf-feature-entry.scss';

const components = [
	SnfAvatar,
	SnfBadge,
	SnfButton,
	SnfButtonGroup,
	SnfCounter,
	SnfTabbar,
	SnfTab,
	SnfTabGroup,
	SnfToggle,
	SnfToggleField,
	SnfCheckbox,
	SnfCheckboxField,
	SnfRadio,
	SnfRadioField,
	SnfInput,
	SnfProgress,
	SnfRate,
	SnfTag,
	SnfImage,
	SnfFeatureEntry,
	SnfList,
	SnfListItem
];

const install = function(Vue) {
	
  if (install.installed) return;
  components.forEach(component => {
	  
    Vue.component(component.name, component)
	
  });
};
// 判断是否是直接引入文件
if (typeof window !== "undefined" && window.Vue) {
    
  install(window.Vue);
}
export default {
    
  install

}
